==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringExpressionsTreeOrFilteringOperationDescription } from "./WebFilteringExpressionsTreeOrFilteringOperationDescription";
/**
 * @hidden
 */
var WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata, _super);
    function WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.b = function (a) {
        if (WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.a == null) {
            WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.c(WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.a);
        }
        if (a.j(WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.a)) {
            return;
        }
        a.y(WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.a);
    };
    WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:FilteringExpressionsTreeOrFilteringOperation");
    };
    WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.d = function (a) {
        WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.b(a);
        a.aa("WebFilteringExpressionsTreeOrFilteringOperation", function () { return new WebFilteringExpressionsTreeOrFilteringOperationDescription(); });
        a.z("WebFilteringExpressionsTreeOrFilteringOperation", WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.a);
    };
    WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.$t = markType(WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata, 'WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata');
    WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.a = null;
    return WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata;
}(Base));
export { WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringExpressionsTreeOrFilteringOperationDescription } from "./WebFilteringExpressionsTreeOrFilteringOperationDescription";
/**
 * @hidden
 */
var WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata, _super);
    function WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.b = function (a) {
        if (WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.a == null) {
            WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.c(WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.a);
        }
        if (a.k(WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.a);
    };
    WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:FilteringExpressionsTreeOrFilteringOperation");
    };
    WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.d = function (a) {
        WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.b(a);
        a.ac("WebFilteringExpressionsTreeOrFilteringOperation", function () { return new WebFilteringExpressionsTreeOrFilteringOperationDescription(); });
        a.ab("WebFilteringExpressionsTreeOrFilteringOperation", WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.a);
    };
    WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.$t = markType(WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata, 'WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata');
    WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata.a = null;
    return WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata;
}(Base));
export { WebFilteringExpressionsTreeOrFilteringOperationDescriptionMetadata };
